use std::env;

pub struct CommandLineArgs {
    koopa: Option<String>,
    riscv: Option<String>,
    output: Option<String>,
}

impl CommandLineArgs {
    pub fn parse() -> Self {
        let koopa = env::args()
            .position(|s| s == "-koopa")
            .and_then(|idx| env::args().nth(idx + 1));

        let riscv = env::args()
            .position(|s| s == "-riscv")
            .and_then(|idx| env::args().nth(idx + 1));

        let output = env::args()
            .position(|s| s == "-o")
            .and_then(|idx| env::args().nth(idx + 1));

        Self {
            koopa,
            riscv,
            output,
        }
    }

    pub fn koopa(&self) -> Option<&String> {
        self.koopa.as_ref()
    }

    pub fn riscv(&self) -> Option<&String> {
        self.riscv.as_ref()
    }

    pub fn output(&self) -> Option<&String> {
        self.output.as_ref()
    }
}
